@@ -18,21 +18,49 @@
 
 import pathlib
 
-copyright = """
+__all__ = [
+		"__copyright__",
+		"__version__",
+		"modname",
+		"pypi_name",
+		"py_modules",
+		"entry_points",
+		"__license__",
+		"short_desc",
+		"author",
+		"author_email",
+		"github_username",
+		"web",
+		"github_url",
+		"project_urls",
+		"repo_root",
+		"long_description",
+		"install_requires",
+		"extras_require",
+		"classifiers",
+		"keywords",
+		"import_name",
+		]
+
+__copyright__ = """
 2019-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-VERSION = "0.3.2"
+__version__ = "0.3.3"
 
 modname = "domdf_python_tools"
+pypi_name = "domdf_python_tools"
+import_name = "domdf_python_tools"
 py_modules = []
-entry_points = None
+entry_points = {
+		"console_scripts": []
+		}
 
-license = 'LGPLv3+'
+__license__ = "GNU Lesser General Public License v3 or later (LGPLv3+)"
 
-short_desc = 'Helpful functions for Python'
+short_desc = "Helpful functions for Python"
 
-author = "Dominic Davis-Foster"
+__author__ = author = "Dominic Davis-Foster"
 author_email = "dominic@davis-foster.co.uk"
 github_username = "domdfcoding"
 web = github_url = f"https://github.com/domdfcoding/domdf_python_tools"
@@ -45,28 +73,30 @@ project_urls = {
 repo_root = pathlib.Path(__file__).parent
 
 # Get info from files; set: long_description
-long_description = (repo_root / "README.rst").read_text() + '\n'
+long_description = (repo_root / "README.rst").read_text().replace("0.3.3", __version__) + '\n'
 conda_description = """Helpful functions for Python
 
 
 Before installing please ensure you have added the following channels: domdfcoding, conda-forge"""
+__all__.append("conda_description")
+
 install_requires = (repo_root / "requirements.txt").read_text().split('\n')
 extras_require = {'dates': ['pytz>=2019.1'], 'all': ['pytz>=2019.1']}
 
 classifiers = [
 		'Development Status :: 4 - Beta',
 		'Intended Audience :: Developers',
-		'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
 		'Operating System :: OS Independent',
 		'Programming Language :: Python',
+		'Programming Language :: Python :: 3 :: Only',
+		'Topic :: Software Development :: Libraries :: Python Modules',
 		'Programming Language :: Python :: 3.6',
+		'Programming Language :: Python :: Implementation :: CPython',
 		'Programming Language :: Python :: 3.7',
 		'Programming Language :: Python :: 3.8',
-		'Programming Language :: Python :: 3 :: Only',
-		'Programming Language :: Python :: Implementation :: CPython',
 		'Programming Language :: Python :: Implementation :: PyPy',
-		'Topic :: Software Development :: Libraries :: Python Modules',
-		
+		'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
+
 		]
 
 keywords = ""
